==> corekeyboard-2.7.0.tar.gz: corekeyboard-v2.7.0/settings/settings.h <==
/*
	*
	* This file is a part of CoreKeyboard.
	* An on-screenkeyboard for CuboCore Application Suite
	* Copyright 2019 Britanicus <marcusbritanicus@gmail.com>
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, see {http://www.gnu.org/licenses/}.
	*
*/


#pragma once

#include <QtCore>
#include <cprime/settingsmanage.h>

/* Minimum  Width */
#define MINIMUM_BUTTON_SIZE 32

class CKSettings {

public:
	enum Layout {
		Mobile,								// Mobile Mode: Looks similar to the Android keyboard
		Desktop								// Desktop mode: Looks very similar to Desktop keyboard
	};

	enum Mode {
		Fixed,								// The keyboard behaves like a panel, stretches across the width available
		Compact								// The keybaord takes up as small a space possible, and can be moved around
	};

	/* Get the key layout: moble or desktop */
	static int keyboardLayout();

	/* Get the keyboard mode: fixed or compact */
	static int keyboardMode();

	/* Show word suggestions */
	static bool showSuggestions();

	/* Key borders */
	static bool showKeyBorders();

	/* Key Mapping */
	static QString keyMapping();

	/* Extra desktop keys */
	static bool showExtraDesktopKeys();

	/* Keyboard Font */
	static QString buttonFontName();

private:
	static settingsManage *ckSett;
};

==> corekeyboard-2.8.0.tar.gz: corekeyboard-v2.8.0/settings/settings.h <==
/*
	*
	* This file is a part of CoreKeyboard.
	* An on-screenkeyboard for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, see {http://www.gnu.org/licenses/}.
	*
*/


#pragma once

#include <QtCore>
#include <cprime/settingsmanage.h>

/* Minimum  Width */
#define MINIMUM_BUTTON_SIZE 32

class CKSettings {

public:
	enum Layout {
		Mobile,								// Mobile Mode: Looks similar to the Android keyboard
		Desktop								// Desktop mode: Looks very similar to Desktop keyboard
	};

	enum Mode {
        Compact,								// The keybaord takes up as small a space possible, and can be moved around
        Fixed								// The keyboard behaves like a panel, stretches across the width available
	};

	/* Get the key layout: moble or desktop */
	static int keyboardLayout();

	/* Get the keyboard mode: fixed or compact */
	static int keyboardMode();

	/* Show word suggestions */
	static bool showSuggestions();

	/* Key borders */
//	static bool showKeyBorders();

	/* Key Mapping */
	static QString keyMapping();

	/* Extra desktop keys */
	static bool showExtraDesktopKeys();

	/* Keyboard Font */
	static QString buttonFontName();

private:
	static settingsManage *ckSett;
};
